import pytest

from contree_mcp.backend_types import CancelOperationResponse, OperationKind, OperationStatus
from contree_mcp.tools.cancel_operation import CancelOperationOutput, cancel_operation
from tests.conftest import FakeResponse, FakeResponses

from . import TestCase


class TestCancelOperation(TestCase):
    @pytest.fixture
    def fake_responses(self) -> FakeResponses:
        return {
            "GET /operations/{uuid}": FakeResponse(
                body={
                    "uuid": "op-1",
                    "kind": OperationKind.INSTANCE.value,
                    "status": OperationStatus.EXECUTING.value,
                    "created_at": "2024-01-01T00:00:00Z",
                }
            ),
            "DELETE /operations/{uuid}": FakeResponse(
                body=CancelOperationResponse(uuid="op-1", status=OperationStatus.CANCELLED)
            ),
        }

    @pytest.mark.asyncio
    async def test_cancel_success(self) -> None:
        result = await cancel_operation(operation_id="op-1")
        assert isinstance(result, CancelOperationOutput)
        assert result.operation_id == "op-1"



"""Contree MCP tools."""

from .cancel_operation import cancel_operation
from .download import download
from .get_guide import get_guide
from .get_image import get_image
from .get_operation import get_operation
from .import_image import import_image
from .list_files import list_files
from .list_images import list_images
from .list_operations import list_operations
from .read_file import read_file
from .registry_auth import registry_auth
from .registry_token_obtain import registry_token_obtain
from .rsync import rsync
from .run import run
from .set_tag import set_tag
from .upload import upload
from .wait_operations import wait_operations

__all__ = [
    "cancel_operation",
    "download",
    "get_guide",
    "get_image",
    "get_operation",
    "import_image",
    "list_files",
    "list_images",
    "list_operations",
    "read_file",
    "registry_auth",
    "registry_token_obtain",
    "rsync",
    "run",
    "set_tag",
    "upload",
    "wait_operations",
]



import asyncio
import logging
import os
import sys

from contree_mcp.arguments import Parser
from contree_mcp.server import amain


def main() -> None:
    parser = Parser(
        config_files=[os.getenv("CONTREE_MCP_CONFIG", "~/.config/contree/mcp.ini")],
        auto_env_var_prefix="CONTREE_MCP_",
    )
    parser.parse_args()

    logging.basicConfig(level=parser.log_level, format="[%(levelname)s] %(message)s", stream=sys.stderr)
    try:
        asyncio.run(amain(parser))
    except KeyboardInterrupt:
        logging.info("Gracefully exited on keyboard interrupt")


if __name__ == "__main__":
    main()
